Full data set probe_features as defined by Illumina
PROBES_CHR_CHRA data frame with five variables: year, sex,
name, n and prop (n divided by total number
of applicants in that year, which means proportions are of people of
that sex with that name born in that year).