R/pivot_to_long_format.R
pivot_to_long_format.RdGet the pivot in long format instead of wide format
pivot_to_long_format(
marker,
figure,
group,
subgroup,
phenotype_column,
sample_sheet,
areas_selection = NULL
)marker to filer HYPER, HYPO, BOTH
DELTAS, DELTAQ,DELTAR, MUTATIONS
GENE, DMR ...
TSS1500 ...
column from the sample sheet to pair to each sample
sample sheet of samples
genomic area to select, if NULL all areas will be selected
the pivot in a long format of 3 columnns, the phontype column with name phenotype, the value of the marker and the area investigated