read multiple bed with annotated data as per input parameter

read_multiple_bed(sample_group, marker, figure)

Arguments

sample_group

name of the population used to build the data path

marker

marker definition used to label folder and files eg MUTATIONS, LESIONS

figure

figures like hypo/hyper to built the data path

Value

list of pivot by column identified with column Label and by Sample