This function returns OMIM phenotypes given a match of a search term in the text meta field of OMIM phenotype entries. Recursive apply (rapply) and grep is used because phenotypeMimNumber is not always present in the same XML structure.

search_phenotype(search_term = "noonan syndrome", show_query = FALSE, mykey)

Arguments

show_query

Show API query. Default is FALSE.

series

Search term. Default is "noonan syndrome".

Examples

search_phenotype(search_term = 'noonan syndrome')
#> Error in search_phenotype(search_term = "noonan syndrome"): object 'my_key' not found