R/analyze_population.R
analyze_population.RdCalculate stochastic epi mutations from a methylation dataset as outcome report of pivot
analyze_population(
signal_data,
sample_sheet,
signal_thresholds,
probe_features
)files into the result folder with pivot table and bedgraph.