R/association_analysis.R
association_analysis.RdAssociation analysis of SEMseeker's results
association_analysis(
inference_details,
result_folder,
maxResources = 90,
parallel_strategy = "multicore",
start_fresh = FALSE,
...
)independent variable: deve essere nalla sample sheet passata a semseeker quando lo abbiamo eseguito la prima volta tipo di regressioni: gaussian, poisson, binomial,quantreg_tau_runs(both as number) eg quantreg_0.25_2000 tipi di test: wilcoxon, stats::t.test, tipi di correlazioni: pearson, kendall, spearman MUTATIONS_* ~ tcdd_mother + exam_age transformation to be applied to dependent variable (mutations and lesions): scale, log, log2, log10, exp, none, quantile_quantiles(as number) eg quantile_3 DEPTH analysis: 1: sample level 2: type level (gene, DMR, cpgisland) (includes 1) 3: genomic area: gene, body, gene tss1550, gene whole, gene tss200, (includes 1 and 2) filter_p_value report after adjusting saves only significant nominal p-value
where semseeker's results are stored, the root folder
percentage of max system's resource to use
which strategy to use for parallel execution see future vignete: possible values, none, multisession,sequential, multicore, cluster
other options to filter elaborations