init ssEnvonment
init_env(result_folder, maxResources = 90, ...)where result of semseeker will bestored
percentage of how many available cores will be used default 90 percent, rounded to the lowest integer
other options to filter elaborations
which strategy to use for parallel executio see future vignete: possibile values, none, multisession,sequential, multicore, cluster
the working ssEnvonment