R/manhattan_plot_marker_per_probe.R
manhattan_plot_marker_per_probe.RdTitle manhattan_plot_marker_per_probe
manhattan_plot_marker_per_probe(
probe_name_max = "cg11680158",
probe_name_min = "cg11680158",
max_sample = 0,
min_sample = 0,
min_signal_probe = 0,
label_font_size = 3,
hyper_color = "blue",
hypo_color = "orange",
non_outlier_color = "grey",
limit_label_color = "blue",
limit_line_color = "red",
limit_line_color_median = "black",
reference_samples_color = "cyan",
show_labels = TRUE,
result_folder = result_folder,
maxResources = maxResources,
parallel_strategy = parallel_strategy,
...
)cg name of the probe to represent tyh probe with maximum burden
cg name of the probe to represent tyh probe with miniumal burden
max number of samples to plot
min number of samples to plot
min signal value of the probe to be plotted
size of the labels
color to assign to hypermethylated probes
color to assign to hypomethylated probes
color to assign to probes that are not outliers
color to assign to the labels of the limit lines
color to assign to the limit lines
color to assign to the median limit line
color to assign to the reference samples
show labels in the plot
foder where the results are stored
percentage of max system's resource to use
strategy to use for parallelization
other parameter