R/read_multiple_bed.R
read_multiple_bed.Rd
read multiple bed with annotated data as per input parameter
read_multiple_bed(sample_group, marker, figure)
name of the population used to build the data path
marker definition used to label folder and files eg MUTATIONS, LESIONS
figures like hypo/hyper to built the data path
list of pivot by column identified with column Label and by Sample